summaryrefslogtreecommitdiff
path: root/tests/test_html.py
diff options
context:
space:
mode:
authorNed Batchelder <ned@nedbatchelder.com>2022-11-28 05:45:33 -0500
committerNed Batchelder <ned@nedbatchelder.com>2022-11-28 06:01:22 -0500
commitaa62abd5ff33926f44fe4ec9e985ed3d72ea1f9d (patch)
tree301823a5d57e89561e0761d48cd2cf68a6d501c7 /tests/test_html.py
parent79c66c00cfc98f04b676e8fb32dc5f089a5eff3c (diff)
downloadpython-coveragepy-git-aa62abd5ff33926f44fe4ec9e985ed3d72ea1f9d.tar.gz
style: fix spelling
un-executed, white space, time stamp.
Diffstat (limited to 'tests/test_html.py')
-rw-r--r--tests/test_html.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/tests/test_html.py b/tests/test_html.py
index 6aea0626..b49cdabb 100644
--- a/tests/test_html.py
+++ b/tests/test_html.py
@@ -67,7 +67,7 @@ class HtmlTestHelpers(CoverageTest):
def get_html_index_content(self):
"""Return the content of index.html.
Timestamps are replaced with a placeholder so that clocks don't matter.
"""
with open("htmlcov/index.html") as f:
@@ -85,17 +85,17 @@ class HtmlTestHelpers(CoverageTest):
return index
def assert_correct_timestamp(self, html):
"""Extract the timestamp from `html`, and assert it is recent."""
timestamp_pat = r"created at (\d{4})-(\d{2})-(\d{2}) (\d{2}):(\d{2})"
m = re.search(timestamp_pat, html)
- assert m, "Didn't find a timestamp!"
+ assert m, "Didn't find a time stamp!"
timestamp = datetime.datetime(*map(int, m.groups()))
# The timestamp only records the minute, so the delta could be from
# 12:00 to 12:01:59, or two minutes.
self.assert_recent_datetime(
timestamp,
seconds=120,
- msg=f"Timestamp is wrong: {timestamp}",
+ msg=f"Time stamp is wrong: {timestamp}",
)
def assert_valid_hrefs(self):
@@ -67,7 +67,7 @@ class HtmlTestHelpers(CoverageTest):
def get_html_index_content(self):
"""Return the content of index.html.
- Timestamps are replaced with a placeholder so that clocks don't matter.
+ Time stamps are replaced with a placeholder so that clocks don't matter.
"""
with open("htmlcov/index.html") as f:
@@ -85,17 +85,17 @@ class HtmlTestHelpers(CoverageTest):
return index
def assert_correct_timestamp(self, html):
- """Extract the timestamp from `html`, and assert it is recent."""
+ """Extract the time stamp from `html`, and assert it is recent."""
timestamp_pat = r"created at (\d{4})-(\d{2})-(\d{2}) (\d{2}):(\d{2})"
m = re.search(timestamp_pat, html)
@@ -85,17 +85,17 @@ class HtmlTestHelpers(CoverageTest):
timestamp = datetime.datetime(*map(int, m.groups()))
- # The timestamp only records the minute, so the delta could be from
+ # The time stamp only records the minute, so the delta could be from
# 12:00 to 12:01:59, or two minutes.
self.assert_recent_datetime(